# pymgcv: Generalized Additive Models in Python

**pymgcv** provides a Python interface to R's powerful [mgcv](https://cran.r-project.org/web/packages/mgcv/index.html) library for fitting Generalized Additive Models (GAMs).

## 📚 Documentation
All the information and examples you need are in the **documentation**:

- [Check out the documentation here!](https://danielward27.github.io/pymgcv/)
